chat_secure_guard library

Classes

ChatSecureGuard
DoubleRatchet
Implements a simplified Double Ratchet algorithm similar to Signal/WhatsApp.
EncryptionService
FileCrypto
KeyManager
RatchetSession
Represents the state of a secure chatting session. This must be persisted securely by the app.

Exceptions / Errors

ChatSecureGuardException
Library for data models used in the chat_secure_guard package. Currently empty as usage relies on primitive types and standard library classes.